Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1169)

Unified Diff: content/public/renderer/content_renderer_client.h

Issue 783003002: Introduce media::RendererFactory interface. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix html_viewer Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/renderer/content_renderer_client.h
diff --git a/content/public/renderer/content_renderer_client.h b/content/public/renderer/content_renderer_client.h
index 9a6c695d5df5f0bea350beaa205d6919a6439fcd..1402ad6789ddd4eb9c5b461632a7b4e7a63181b5 100644
--- a/content/public/renderer/content_renderer_client.h
+++ b/content/public/renderer/content_renderer_client.h
@@ -53,7 +53,7 @@ struct WebURLError;
}
namespace media {
-class Renderer;
+class RendererFactory;
struct KeySystemInfo;
}
@@ -257,11 +257,9 @@ class CONTENT_EXPORT ContentRendererClient {
// Returns true if the page at |url| can use Pepper MediaStream APIs.
virtual bool AllowPepperMediaStreamAPI(const GURL& url);
- // Allows an embedder to create a media::Renderer. The caller owns the
- // returned renderer.
- virtual scoped_ptr<media::Renderer> CreateMediaRenderer(
- RenderFrame* render_frame,
- const scoped_refptr<base::SingleThreadTaskRunner>& task_runner);
+ // Allows an embedder to provide a media::RendererFactory.
+ virtual scoped_ptr<media::RendererFactory> GetMediaRendererFactory(
gunsch 2014/12/09 04:26:09 naming nit: I think "Get..." usually implies a sin
jam 2014/12/09 17:14:19 if this is switched to a factory now, why do we ne
xhwang 2014/12/09 18:05:51 I felt using scoped_ptr makes the lifetime/ownersh
xhwang 2014/12/09 18:05:52 Done.
jam 2014/12/10 20:14:46 Is this factory per render frame? or is there one
xhwang 2014/12/10 20:22:54 For now, the factory is per render frame. We may b
+ RenderFrame* render_frame);
// Gives the embedder a chance to register the key system(s) it supports by
// populating |key_systems|.
« no previous file with comments | « no previous file | content/public/renderer/content_renderer_client.cc » ('j') | media/filters/default_renderer_factory.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698